##  Build a Custom Integration Using the Integration API
We offer the Integration API that enables you to build a custom integration according to your use case and requirements while investing less effort and resources compared to other alternative solutions. For more information, see [Integration API](https://help.sap.com/docs/leanix/ea/integration-api?locale=en-US&state=PRODUCTION&version=CLOUD "Overview of the Integration API.").
Advantages:
  * The Integration API allows you to significantly reduce the amount of resources and requirements that you need on your end. Instead of implementing an entire integration from scratch, you need to configure the external system to provide or consume relevant data using our custom [LeanIX Data Interchange Format (LDIF)](https://help.sap.com/docs/leanix/ea/integration-api?locale=en-US&state=PRODUCTION&version=CLOUD#loio275a99087a441014a04fa6cda4e0ec2b__leanix_data_interchange_format_ldif) format.
  * Anyone with sufficient technical knowledge can operate and maintain the actual mapping of your custom integration. You don't need a dedicated engineering team for that.
  * To assist you with setting up an appropriate configuration for your use case, we provide comprehensive documentation and offer guidance through our Customer Success Team.


Disadvantages:
  * You need to use a middleware to consume or provide your data in the LDIF format.
  * While you don't need a professional engineering background, investing time in learning the language of the processor configurations within the Integration API may be necessary.
  * Developing and maintaining the processor configuration does not provide the same developer experience that you may be accustomed to with other implementation solutions. This relates to possibilities such as auto-completion, debugging, or automated testing.
  * The Integration API does not support real-time synchronization of data.


YesNo
Send
![close icon](https://consent.trustarc.com/get?name=sapglow-close-icon.png)
This site uses cookies and related technologies, as described in our Cookie Statement, for purposes that may include site operation, analytics, enhanced user experience, or advertising. You may choose to consent to our use of these technologies, or manage your own preferences.
Understood Manage Settings
[Privacy Statement](https://help.sap.com/docs/privacy)|[Cookie Statement](https://www.sap.com/about/legal/privacy/cookies.html)
